from django.apps import AppConfig


class DjangoSimpleThirdPartyJWTDevDashboardConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "django_simple_third_party_jwt_dev_dashboard"
